@@ -364,6 +364,17 @@ class XY(Operation):
     par_domain = "R"
     grad_method = "A"
 
+    @staticmethod
+    def decomposition(phi, wires):
+        return [
+            qml.Hadamard(wires=[wires[0]]),
+            qml.CY(wires=wires),
+            qml.RY(phi / 2, wires=[wires[0]]),
+            qml.RX(-phi / 2, wires=[wires[1]]),
+            qml.CY(wires=wires),
+            qml.Hadamard(wires=[wires[0]]),
+        ]
+
     @classmethod
     def _matrix(cls, *params):
         phi = params[0]
@@ -411,6 +422,14 @@ class XX(Operation):
     par_domain = "R"
     grad_method = "A"
 
+    @staticmethod
+    def decomposition(phi, wires):
+        return [
+            qml.CNOT(wires=wires),
+            qml.RX(phi, wires=[wires[0]]),
+            qml.CNOT(wires=wires),
+        ]
+
     @classmethod
     def _matrix(cls, *params):
         phi = params[0]
@@ -458,6 +477,14 @@ class YY(Operation):
     par_domain = "R"
     grad_method = "A"
 
+    @staticmethod
+    def decomposition(phi, wires):
+        return [
+            qml.CY(wires=wires),
+            qml.RY(phi, wires=[wires[0]]),
+            qml.CY(wires=wires),
+        ]
+
     @classmethod
     def _matrix(cls, *params):
         phi = params[0]
@@ -505,6 +532,14 @@ class ZZ(Operation):
     par_domain = "R"
     grad_method = "A"
 
+    @staticmethod
+    def decomposition(phi, wires):
+        return [
+            qml.CNOT(wires=wires),
+            qml.RZ(phi, wires=[wires[1]]),
+            qml.CNOT(wires=wires),
+        ]
+
     @classmethod
     def _matrix(cls, *params):
         phi = params[0]
